package software.eskimo.capacitor.sockets;

import android.util.Log;
import java.util.ArrayList;
import java.util.List;

public class Sockets implements SocketHandler.SocketDelegate {

    private List<SocketHandler> sockets = new ArrayList<>();
    private SocketsPlugin plugin;

    public Sockets(SocketsPlugin plugin) {
        this.plugin = plugin;
    }

    public SocketHandler create(String id) {
        SocketHandler socket = new SocketHandler(id, this);
        sockets.add(socket);
        return socket;
    }

    public void connect(String id, String host, int port, boolean useTLS, boolean acceptInvalidCertificates, String delimiter) {
        SocketHandler socket = getSocketById(id);
        if (socket != null) {
            socket.connect(host, port, useTLS, acceptInvalidCertificates, delimiter);
        }
    }

    public void send(String id, String message) {
        SocketHandler socket = getSocketById(id);
        if (socket != null) {
            socket.send(message);
        }
    }

    public void disconnect(String id) {
        SocketHandler socket = getSocketById(id);
        if (socket != null) {
            socket.disconnect();
            sockets.remove(socket);
        }
    }

    public int getActiveSocketCount() {
        return sockets.size();
    }

    private SocketHandler getSocketById(String id) {
        for (SocketHandler socket : sockets) {
            if (socket.getId().equals(id)) {
                return socket;
            }
        }
        return null;
    }

    @Override
    public void onStateChanged(String socketId, String state) {
        Log.d("Sockets", "Socket state changed: " + state);
        plugin.notifyStateListeners("state", socketId, state);
    }

    @Override
    public void onMessageReceived(String socketId, String message) {
        Log.d("Sockets", "Socket message received: " + message);
        plugin.notifyMessageListeners(socketId, message);
    }
}